@@ -12,6 +12,7 @@ Changes for Python3 port © 2011-14 Scott Kitterman <scott@kitterman.com>
 """
 
 import socket, string, types, time, select
+import errno
 from . import Type,Class,Opcode
 import asyncore
 #
@@ -93,7 +94,7 @@ class DnsRequest:
     """ high level Request object """
     def __init__(self,*name,**args):
         self.donefunc=None
-        self.async=None
+        self.py3async=None
         self.defaults = {}
         self.argparse(name,args)
         self.defaults = self.args
@@ -212,8 +213,8 @@ class DnsRequest:
                 self.s.bind(('', source_port))
                 break
             except socket.error as msg: 
-                # Error 98, 'Address already in use'
-                if msg.errno != 98: raise
+                # errno.EADDRINUSE, 'Address already in use'
+                if msg.errno != errno.EADDRINUSE: raise
 
     def conn(self):
         self.getSource()
@@ -273,7 +274,7 @@ class DnsRequest:
                 self.sendTCPRequest(server)
         except socket.error as reason:
             raise SocketError(reason)
-        if self.async:
+        if self.py3async:
             return None
         else:
             return self.response
@@ -285,7 +286,7 @@ class DnsRequest:
         #    raise ArgumentError, 'reinitialize request before reuse'
         try:
             if self.args['resulttype']:
-                raise ArgumentError('Restulttype {0} set with DNS.req, use DNS.qry to specify result type.'(format(self.args['resulttype'])))
+                raise ArgumentError('Restulttype {0} set with DNS.req, use DNS.qry to specify result type.'.format(self.args['resulttype']))
         except:
             # resulttype isn't set and that's what we want for DNS.req
             pass
@@ -325,7 +326,7 @@ class DnsRequest:
                 self.sendTCPRequest(server)
         except socket.error as reason:
             raise SocketError(reason)
-        if self.async:
+        if self.py3async:
             return None
         else:
             return self.response
@@ -346,7 +347,7 @@ class DnsRequest:
                     # TODO. Handle timeouts &c correctly (RFC)
                     self.time_start=time.time()
                     self.conn()
-                    if not self.async:
+                    if not self.py3async:
                         self.s.send(self.request)
                         r=self.processUDPReply()
                         # Since we bind to the source port and connect to the
@@ -359,7 +360,7 @@ class DnsRequest:
                         self.response = r
                         # FIXME: check waiting async queries
                 finally:
-                    if not self.async:
+                    if not self.py3async:
                         self.s.close()
             except socket.error as e:
                 # Keep trying more nameservers, but preserve the first error
@@ -428,7 +429,7 @@ class DnsAsyncRequest(DnsRequest,asyncore.dispatcher_with_send):
         else:
             self.donefunc=self.showResult
         #self.realinit(name,args) # XXX todo
-        self.async=1
+        self.py3async=1
     def conn(self):
         self.getSource()
         self.connect((self.ns,self.port))
